@@ -3,13 +3,20 @@ package Gruntmaster::App::Command::Set;
 use 5.014000;
 use warnings;
 
-our $VERSION = '5999.000_015';
+our $VERSION = '5999.000_016';
 
 use Gruntmaster::App '-command';
 use Gruntmaster::Data;
 
 use File::Slurp qw/read_file/;
 
+use constant PAGES => {
+	contests => '/ct/',
+	jobs     => '/log/',
+	problems => '/pb/',
+	users    => '/us/',
+};
+
 sub opt_spec {
 	['file!', 'Use the contents of a file as value']
 }
@@ -29,6 +36,7 @@ sub execute {
 	my ($id, %values) = @$args;
 	%values = map { $_ => scalar read_file $values{$_} } keys %values if $opt->{file};
 	db->update($self->app->table, \%values, {id => $id});
+	purge PAGES->{$self->app->table}.$_ for '', $id;
 }
 
 1;
@@ -63,7 +71,7 @@ Marius Gavrilescu, E<lt>marius@ieval.roE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2015 by Marius Gavrilescu
+Copyright (C) 2014-2016 by Marius Gavrilescu
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.20.1 or,
