@@ -3,8 +3,8 @@ use 5.014;
 use warnings;
 
 use parent qw/Exporter/;
-our $VERSION = '5999.000_015';
-our @EXPORT = qw/dbinit purge db user_list user_entry problem_list problem_entry contest_list contest_entry contest_has_problem job_list job_entry create_job standings update_status rerun_job take_job finish_job open_problem/;
+our $VERSION = '5999.000_016';
+our @EXPORT = qw/dbinit purge db user_list user_entry problem_list problem_entry contest_list contest_entry contest_has_problem job_list job_entry create_job standings update_status rerun_job rerun_problem take_job finish_job open_problem/;
 our @EXPORT_OK = @EXPORT;
 
 use JSON::MaybeXS qw/decode_json/;
@@ -36,6 +36,7 @@ my %statements = (
 
 	job_entry_sth => 'SELECT * FROM job_entry WHERE id = ?',
 
+	rerun_problem_sth => 'UPDATE jobs SET daemon=NULL,result=-2,result_text=NULL,results=NULL,errors=NULL WHERE problem = ?',
 	rerun_job_sth => 'UPDATE jobs SET daemon=NULL,result=-2,result_text=NULL,results=NULL,errors=NULL WHERE id = ?',
 	take_job_sth => 'UPDATE jobs SET daemon=? WHERE id = (SELECT id FROM jobs WHERE daemon IS NULL LIMIT 1 FOR UPDATE) RETURNING id',
 );
@@ -242,6 +243,12 @@ sub update_status {
 	$db->commit
 }
 
+sub rerun_problem {
+	my ($problem) = @_;
+	_query rerun_problem_sth => $problem;
+	purge '/log/';
+}
+
 sub rerun_job {
 	my ($id) = @_;
 	_query rerun_job_sth => $id;
@@ -263,6 +270,7 @@ sub finish_job {
 	db->update(jobs => \%args, {id => $job->{id}});
 	purge '/log/';
 	purge '/log/' . $job->{id};
+	purge '/st/' . $job->{contest} if $job->{contest};
 	return if $private;
 	my $status = {
 		problem => $job->{problem},
@@ -467,7 +475,7 @@ Marius Gavrilescu E<lt>marius@ieval.roE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2014-2015 by Marius Gavrilescu
+Copyright (C) 2014-2016 by Marius Gavrilescu
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.20.1 or,
